@@ -22,13 +22,15 @@ from .widget import Widget
 
 @dataclass_json
 @dataclass
-class Section(object):
+class Section(Renderable):
   """Section
 
   Describes a Google Chat App response Section.
 
   https://developers.google.com/chat/api/guides/message-formats/cards#sections_and_widgets
   """
+  __no_root_level__ = True
+
   header: Optional[str] = standard_field()
   widgets: Optional[List[Widget]] = list_field(default_factory=list)
   collapsible: bool = standard_field()
