@@ -14,26 +14,26 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
-from typing import Any, List, Mapping
+from typing import List
 
 from card_framework import enum_field, list_field, standard_field, AutoNumber
-from dataclasses_json import LetterCase, dataclass_json
+from dataclasses_json import dataclass_json
 
 from ..widget import Widget
 
 
-@dataclass_json(letter_case=LetterCase.CAMEL)
+@dataclass_json
 @dataclass
 class Action(Widget):
   class Interaction(AutoNumber):
-    UNSPECIFIED = 'UNSPECIFIED'
-    OPEN_DIALOG = 'OPEN_DIALOG'
+    UNSPECIFIED = ()
+    OPEN_DIALOG = ()
 
   class LoadIndicator(AutoNumber):
     """LoadIndicator
     """
-    SPINNER = 'SPINNER'
-    NONE = 'NONE'
+    SPINNER = ()
+    NONE = ()
 
   function: str = standard_field(default='')
   parameters: List[ActionParameter] = list_field()
@@ -41,35 +41,9 @@ class Action(Widget):
   persist_values: bool = standard_field()
   interaction: Interaction = enum_field()
 
-  @property
-  def _widget_tag(self) -> str:
-    """The widget tag name.
 
-    Returns:
-        str: The key by which the widget will be rendered in the Section.
-    """
-    return 'action'
-
-
-@dataclass_json(letter_case=LetterCase.CAMEL)
+@dataclass_json
 @dataclass
-class ActionParameter(Widget):
+class ActionParameter(object):
   key: str = standard_field()
   value: str = standard_field()
-
-  @property
-  def _widget_tag(self) -> str:
-    """The widget tag name.
-
-    Returns:
-        str: The key by which the widget will be rendered in the Section.
-    """
-    return 'actionParameter'
-
-  def render(self) -> Mapping[str, Any]:
-    """Renders the response to json.
-
-    Returns:
-        Mapping[str, Any]: _description_
-    """
-    return self.to_dict()
